#[non_exhaustive]pub enum DecodingError {
OutOfMemory,
MemoryLimit,
DecoderNotFound,
EndCodeNotFound,
UnexpectedEof,
LzwError(LzwError),
Format(DecodingFormatError),
Io(Error),
}Expand description
Decoding error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutOfMemory
Failed to internally allocate a buffer of sufficient size.
MemoryLimit
Allocation exceeded set memory limit
DecoderNotFound
Expected a decoder but none found.
EndCodeNotFound
Expected an end-code, but none found.
UnexpectedEof
Decoding could not complete as the reader completed prematurely.
LzwError(LzwError)
Error encountered while decoding an LZW stream.
Format(DecodingFormatError)
Returned if the image is found to be malformed.
Io(Error)
Wraps std::io::Error.